@@ -51,7 +51,7 @@ module Data.ListLike
                  -- ** Unfolding
                  -- * Sublists
                  -- ** Extracting sublists
-                 take, drop, splitAt, takeWhile, dropWhile, span, break,
+                 take, drop, splitAt, takeWhile, dropWhile, dropWhileEnd, span, break,
                  group, inits, tails, 
                  -- ** Predicates
                  isPrefixOf, isSuffixOf, isInfixOf,
@@ -112,15 +112,17 @@ module Data.ListLike
 import Prelude hiding (length, head, last, null, tail, map, filter, concat, 
                        any, lookup, init, all, foldl, foldr, foldl1, foldr1,
                        maximum, minimum, iterate, span, break, takeWhile,
-                       dropWhile, reverse, zip, zipWith, sequence,
+                       dropWhile, dropWhileEnd, reverse, zip, zipWith, sequence,
                        sequence_, mapM, mapM_, concatMap, and, or, sum,
                        product, repeat, replicate, cycle, take, drop,
                        splitAt, elem, notElem, unzip, lines, words,
-                       unlines, unwords)
+                       unlines, unwords, foldMap)
 import Data.ListLike.Base
 import Data.ListLike.CharString
 import Data.ListLike.FoldableLL
 import Data.ListLike.Instances()
+import Data.ListLike.DList
+import Data.ListLike.FMList
 import Data.ListLike.String
 import Data.ListLike.Utils
 import Data.ListLike.IO
